## Metadata

Here are some of the custom classes that people might find useful when writing the metadata fields of the dataloaders.

## Available classes

<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/metadata.py#L7)</span>
### GenomicRanges

```python
kipoi.metadata.GenomicRanges(chr, start, end, id, strand='*')
```

